import { Directive, ElementRef, Input, Output, EventEmitter } from '@angular/core';
import { FlatpickrDefaults } from './flatpickr-defaults.service';
import * as Flatpickr from 'flatpickr';
var FlatpickrDirective = (function () {
    function FlatpickrDirective(elm, defaults) {
        this.elm = elm;
        this.defaults = defaults;
        /**
         * @hidden
         */
        this.ngModelChange = new EventEmitter();
        /**
         * Gets triggered once the calendar is in a ready state
         */
        this.flatpickrReady = new EventEmitter();
        /**
         * Gets triggered when the user selects a date, or changes the time on a selected date.
         */
        this.flatpickrChange = new EventEmitter();
        /**
         * Gets triggered when the input value is updated with a new date string.
         */
        this.flatpickrValueUpdate = new EventEmitter();
        /**
         * Gets triggered when the calendar is opened.
         */
        this.flatpickrOpen = new EventEmitter();
        /**
         * Gets triggered when the calendar is closed.
         */
        this.flatpickrClose = new EventEmitter();
        /**
         * Gets triggered when the month is changed, either by the user or programmatically.
         */
        this.flatpickrMonthChange = new EventEmitter();
        /**
         * Gets triggered when the year is changed, either by the user or programmatically.
         */
        this.flatpickrYearChange = new EventEmitter();
        /**
         * Take full control of every date cell with this output
         */
        this.flatpickrDayCreate = new EventEmitter();
    }
    FlatpickrDirective.prototype.ngAfterViewInit = function () {
        var _this = this;
        var defaultDate = this.ngModel;
        if (this.mode === 'range' && typeof defaultDate === 'object' && !(defaultDate instanceof Date) && !Array.isArray(defaultDate)) {
            defaultDate = defaultDate.from.toISOString() + " to " + defaultDate.to.toISOString();
        }
        var options = {
            altFormat: this.altFormat,
            altInput: this.altInput,
            altInputClass: this.altInputClass,
            allowInput: this.allowInput,
            appendTo: this.appendTo,
            clickOpens: this.clickOpens,
            dateFormat: this.dateFormat,
            defaultDate: defaultDate,
            disable: this.disable,
            disableMobile: this.disableMobile,
            enable: this.enable,
            enableTime: this.enableTime,
            enableSeconds: this.enableSeconds,
            hourIncrement: this.hourIncrement,
            inline: this.inline,
            maxDate: this.maxDate,
            minDate: this.minDate,
            minuteIncrement: this.minuteIncrement,
            mode: this.mode,
            nextArrow: this.nextArrow,
            noCalendar: this.noCalendar,
            parseDate: this.parseDate,
            prevArrow: this.prevArrow,
            shorthandCurrentMonth: this.shorthandCurrentMonth,
            static: this.static,
            time24hr: this.time24hr,
            utc: this.utc,
            weekNumbers: this.weekNumbers,
            getWeek: this.getWeek,
            wrap: this.wrap,
            plugins: this.plugins,
            onChange: function (selectedDates, dateString, instance) {
                _this.flatpickrChange.emit({ selectedDates: selectedDates, dateString: dateString, instance: instance });
            },
            onOpen: function (selectedDates, dateString, instance) {
                _this.flatpickrOpen.emit({ selectedDates: selectedDates, dateString: dateString, instance: instance });
            },
            onClose: function (selectedDates, dateString, instance) {
                _this.flatpickrClose.emit({ selectedDates: selectedDates, dateString: dateString, instance: instance });
            },
            onMonthChange: function (selectedDates, dateString, instance) {
                _this.flatpickrMonthChange.emit({ selectedDates: selectedDates, dateString: dateString, instance: instance });
            },
            onYearChange: function (selectedDates, dateString, instance) {
                _this.flatpickrYearChange.emit({ selectedDates: selectedDates, dateString: dateString, instance: instance });
            },
            onReady: function (selectedDates, dateString, instance) {
                _this.flatpickrReady.emit({ selectedDates: selectedDates, dateString: dateString, instance: instance });
            },
            onValueUpdate: function (selectedDates, dateString, instance) {
                _this.flatpickrValueUpdate.emit({ selectedDates: selectedDates, dateString: dateString, instance: instance });
            },
            onDayCreate: function (selectedDates, dateString, instance, dayElement) {
                _this.flatpickrDayCreate.emit({ selectedDates: selectedDates, dateString: dateString, instance: instance, dayElement: dayElement });
            }
        };
        if (this.locale) {
            options.locale = this.locale;
        }
        Object.keys(options).forEach(function (key) {
            if (typeof options[key] === 'undefined') {
                options[key] = _this.defaults[key];
            }
        });
        options.time_24hr = options.time24hr;
        this.instance = new Flatpickr(this.elm.nativeElement, options);
    };
    FlatpickrDirective.prototype.ngOnChanges = function (changes) {
        var _this = this;
        if (this.instance) {
            for (var inputKey in changes) {
                this.instance.set(inputKey, this[inputKey]);
            }
        }
        if (changes.ngModel && this.convertModelValue) {
            setTimeout(function () {
                if (typeof _this.ngModel === 'string') {
                    switch (_this.mode) {
                        case 'multiple':
                            var dates = _this.ngModel.split('; ').map(function (str) { return new Date(str); });
                            _this.ngModelChange.emit(dates);
                            break;
                        case 'range':
                            var _a = _this.ngModel.split(' to ').map(function (str) { return new Date(str); }), from = _a[0], to = _a[1];
                            _this.ngModelChange.emit({ from: from, to: to });
                            break;
                        case 'single':
                        default:
                            _this.ngModelChange.emit(new Date(_this.ngModel));
                            break;
                    }
                }
            });
        }
    };
    FlatpickrDirective.prototype.ngOnDestroy = function () {
        this.instance.destroy();
    };
    return FlatpickrDirective;
}());
export { FlatpickrDirective };
FlatpickrDirective.decorators = [
    { type: Directive, args: [{
                selector: '[mwlFlatpickr]'
            },] },
];
/** @nocollapse */
FlatpickrDirective.ctorParameters = function () { return [
    { type: ElementRef, },
    { type: FlatpickrDefaults, },
]; };
FlatpickrDirective.propDecorators = {
    'altFormat': [{ type: Input },],
    'altInput': [{ type: Input },],
    'altInputClass': [{ type: Input },],
    'allowInput': [{ type: Input },],
    'appendTo': [{ type: Input },],
    'clickOpens': [{ type: Input },],
    'dateFormat': [{ type: Input },],
    'disable': [{ type: Input },],
    'disableMobile': [{ type: Input },],
    'enable': [{ type: Input },],
    'enableTime': [{ type: Input },],
    'enableSeconds': [{ type: Input },],
    'hourIncrement': [{ type: Input },],
    'inline': [{ type: Input },],
    'maxDate': [{ type: Input },],
    'minDate': [{ type: Input },],
    'minuteIncrement': [{ type: Input },],
    'mode': [{ type: Input },],
    'nextArrow': [{ type: Input },],
    'noCalendar': [{ type: Input },],
    'parseDate': [{ type: Input },],
    'prevArrow': [{ type: Input },],
    'shorthandCurrentMonth': [{ type: Input },],
    'static': [{ type: Input },],
    'time24hr': [{ type: Input },],
    'utc': [{ type: Input },],
    'weekNumbers': [{ type: Input },],
    'getWeek': [{ type: Input },],
    'wrap': [{ type: Input },],
    'plugins': [{ type: Input },],
    'locale': [{ type: Input },],
    'convertModelValue': [{ type: Input },],
    'ngModel': [{ type: Input },],
    'ngModelChange': [{ type: Output },],
    'flatpickrReady': [{ type: Output },],
    'flatpickrChange': [{ type: Output },],
    'flatpickrValueUpdate': [{ type: Output },],
    'flatpickrOpen': [{ type: Output },],
    'flatpickrClose': [{ type: Output },],
    'flatpickrMonthChange': [{ type: Output },],
    'flatpickrYearChange': [{ type: Output },],
    'flatpickrDayCreate': [{ type: Output },],
};
//# sourceMappingURL=flatpickr.directive.js.map